@@ -1,10 +1,11 @@
 from .base_function import BaseFunction
 from .benchmarks import RastriginFunction
-from .neural_network import RootMeanSquaredErrorForNN
+from .neural_network import RootMeanSquaredErrorForNN, R2ScoreForNN
 
 
 __all__ = [
     'BaseFunction',
     'RastriginFunction',
     'RootMeanSquaredErrorForNN',
+    'R2ScoreForNN',
 ]
